@@ -110,6 +110,15 @@ impl SeatHandler {
     }
 }
 
+impl fmt::Debug for SeatHandler {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        f.debug_struct("SeatHandler")
+            .field("seats", &self.seats)
+            .field("listeners", &"Fn(..) -> { ... }")
+            .finish()
+    }
+}
+
 /// A handle to an seat listener callback
 ///
 /// Dropping it disables the associated callback and frees the closure.
@@ -163,6 +172,12 @@ impl crate::environment::MultiGlobalHandler<wl_seat::WlSeat> for SeatHandler {
     }
 }
 
+impl fmt::Debug for SeatListener {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        f.debug_struct("SeatListener").field("_cb", &"Fn(..) -> { ... }").finish()
+    }
+}
+
 fn process_seat_event(
     seat: Main<wl_seat::WlSeat>,
     event: wl_seat::Event,
